@@ -689,14 +689,21 @@ ews_settings_get_folder_sizes_thread (gpointer user_data)
 				fsd->cancellable, &fsd->error);
 
 		for (l = folders_list; l != NULL; l = l->next) {
+			const EEwsFolder *folder = l->data;
 			const EwsFolderId *folder_id;
 			gchar *folder_full_name;
 			gchar *folder_size;
 
-			folder_id = e_ews_folder_get_id (l->data);
+			if (!folder || e_ews_folder_is_error (folder))
+				continue;
+
+			folder_id = e_ews_folder_get_id (folder);
+			if (!folder_id)
+				continue;
+
 			folder_full_name = camel_ews_store_summary_get_folder_full_name (
 				fsd->ews_store->summary, folder_id->id, NULL);
-			folder_size = g_format_size (e_ews_folder_get_size (l->data));
+			folder_size = g_format_size (e_ews_folder_get_size (folder));
 
 			g_hash_table_insert (fsd->folder_sizes, folder_full_name, folder_size);
 		}
@@ -1191,7 +1198,18 @@ update_ews_source_entries_cb (EShellView *shell_view,
 
 	if (is_ews_source) {
 		if (!source || !e_source_has_extension (source, E_SOURCE_EXTENSION_EWS_FOLDER))
-		    is_ews_source = FALSE;
+			is_ews_source = FALSE;
+
+		if (is_ews_source) {
+			ESource *clicked_source = NULL;
+
+			g_object_get (G_OBJECT (shell_view), "clicked-source", &clicked_source, NULL);
+
+			if (clicked_source && clicked_source != source)
+				is_ews_source = FALSE;
+
+			g_clear_object (&clicked_source);
+		}
 
 		if (is_ews_source) {
 			ESourceEwsFolder *ews_folder = e_source_get_extension (source, E_SOURCE_EXTENSION_EWS_FOLDER);
